
#ifndef _C10_kl492_
#define _C10_kl492_

#ifdef __cplusplus
extern "C" {
#endif

static EIF_REFERENCE F1175_11509_body(EIF_REFERENCE);
extern EIF_REFERENCE F1175_11509(EIF_REFERENCE);
extern void EIF_Minit492(void);

#ifdef __cplusplus
}
#endif

#endif
